@@ -79,12 +79,13 @@ class ArticleAuthorItem(scrapy.Item):
     followers_count = scrapy.Field()   # 粉丝数
     location = scrapy.Field()   # 地区
     mobile = scrapy.Field()   # 手机号
-    sec_uid = scrapy.Field()
+    sec_uid = scrapy.Field()  # 能获取到用户主页的ID
     uid = scrapy.Field()   # 用户ID
     unique_id = scrapy.Field()   # 唯一ID
     age = scrapy.Field()   # 年龄
     other_info = scrapy.Field()   # 其它
     ip_label = scrapy.Field()   # IP标签
+    gender = scrapy.Field()   # 性别
     upload_oss = scrapy.Field()
     register_date = scrapy.Field()
     created_date = scrapy.Field()
@@ -164,7 +165,7 @@ def get_comment_item(response, post_result, block, uploadOss=True):
     item["upload_oss"] = uploadOss
     if post_result:
         item["post_url"] = post_result["url"]
-        item["post_id"] = post_result["post_id"]
+        item["post_id"] = post_result.get("post_id")
         item["upload_oss"] = post_result.get('upload_oss', False)
     if response:
         item["url"] = response.url
